"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_1 = require("./fs");
class RemoveSourceMapUrlWebpackPlugin {
    constructor({ fileNameRegex = /\.(js|css)$/ } = {}) {
        this.fileNameRegex = fileNameRegex;
    }
    apply(compiler) {
        compiler.hooks.done.tapPromise('RemoveSourceMapUrlWebpackPlugin', async (stats) => {
            const outputPath = stats.compilation.outputOptions.path;
            let fileNames = await fs_1.readdir(outputPath);
            fileNames = fileNames.filter(fileName => this.fileNameRegex.test(fileName));
            for (const fileName of fileNames) {
                const filePath = path_1.default.resolve(outputPath, fileName);
                const data = await fs_1.readFile(filePath, 'utf8');
                const lines = data.split('\n');
                const result = lines
                    .filter(line => !/^.*# sourceMappingURL=(.*\.map).*/.test(line))
                    .join('\n');
                await fs_1.writeFile(filePath, result, 'utf8');
            }
        });
    }
}
exports.default = RemoveSourceMapUrlWebpackPlugin;
//# sourceMappingURL=index.js.map